@@ -261,32 +261,30 @@ class dyn_obj:
                 cur_frame = self.frames[i]
                 cur_zeros = np.arange(0, len(self.frames)-i)
 
-                tmp_coords = np.zeros([int_size, 3])
-                tmp_coords[cur_zeros, :] = 0
-
-                tmp_curve = bpy.data.curves.new(name, type='CURVE')
-                tmp_curve.dimensions = '3D'
-                tmp_curve_curve.resolution_u = 2
+                int_curve = bpy.data.curves.new(name, type='CURVE')
+                
+                int_curve.dimensions = '3D'
+                int_curve.resolution_u = 2
 
                 # map coords to spline
-                tmp_curve_line = tmp_curve_curve.splines.new('NURBS')
-                tmp_curve_line.points.add(len(tmp_coords))
-                for i, coord in enumerate(tmp_coords):
-                    tmp_,tmp_y,tmp_z = coord
-                    tmp_line.points[i].co = (tmp_x, tmp_y, tmp_z, 1)
+                int_line = int_curve.splines.new('NURBS')
+                int_line.points.add(len(int_coords))
+                for i, coord in enumerate(int_coords):
+                    x,y,z = coord
+                    int_line.points[i].co = (x, y, z, 1)
 
                 # create Object
-                tmp_curveOB = bpy.data.objects.new(name, tmp_curve)
+                int_curveOB = bpy.data.objects.new(name, int_curve)
 
                 # attach to scene and validate context
-                bpy.context.collection.objects.link(tmp_curveOB)
+                bpy.context.collection.objects.link(int_curveOB)
                 
-                tmp_curveOB.data.bevel_depth = thickness
-                tmp_curveOB.data.use_fill_caps = True
+                int_curveOB.data.bevel_depth = thickness
+                int_curveOB.data.use_fill_caps = True
 
-                tmp_curveOB.data.bevel_factor_start = 0
+                int_curveOB.data.bevel_factor_start = 0
 
-                curve_to_mesh(tmp_curveOB)
+                curve_to_mesh(int_curveOB)
 
                 tmp_curve_mesh = bpy.data.objects[self.name+'_streamline']
                 
